@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -67,12 +67,13 @@ expr_error_print( Expr *expr, VipsBuf *buf )
 		tool_error( expr->sym->tool, buf );
 	else if( expr->row ) {
 		Workspace *ws = expr->row->ws;
+		Workspacegroup *wsg = workspace_get_workspacegroup( ws );
 
 		vips_buf_appendf( buf, " (" );
 		row_qualified_name( expr->row, buf );
-		if( FILEMODEL( ws )->filename )
+		if( FILEMODEL( wsg )->filename )
 			vips_buf_appendf( buf, " - %s", 
-				FILEMODEL( ws )->filename );
+				FILEMODEL( wsg )->filename );
 		vips_buf_appendf( buf, ")" );
 	}
 
@@ -579,7 +580,8 @@ expr_dirty( Expr *expr, int serial )
 	printf( "\n" );
 #endif /*DEBUG*/
 
-	if( (row = expr_get_row( expr )) ) {
+	if( (row = expr_get_row( expr )) &&
+		row->top_row->sym ) {
 		Symbol *top_sym = row->top_row->sym;
 
 		row_dirty( row, TRUE );
@@ -594,7 +596,8 @@ expr_dirty( Expr *expr, int serial )
 void *
 expr_dirty_intrans( Expr *expr, int serial )
 {
-	if( expr->row ) {
+	if( expr->row &&
+		expr->row->top_row->sym ) {
 		row_dirty_intrans( expr->row, TRUE );
 		symbol_dirty( expr->row->top_row->sym, serial );
 	}
@@ -614,7 +617,8 @@ expr_tip_sub( Expr *expr, VipsBuf *buf )
 		vips_buf_appends( buf, " " );
 	}
 
-	if( compile && is_class( compile ) ) {
+	if( compile && 
+		is_class( compile ) ) {
 		vips_buf_appends( buf, _( "class" ) );
 		vips_buf_appends( buf, " " );
 		if( compile->nparam == 0 ) {
@@ -631,7 +635,7 @@ expr_tip_sub( Expr *expr, VipsBuf *buf )
 	else if( expr->sym->type == SYM_PARAM )
 		vips_buf_appendf( buf, _( "parameter \"%s\"" ), 
 			IOBJECT( expr->sym )->name );
-	else {
+	else if( compile ) {
 		if( is_member( expr->sym ) ) {
 			vips_buf_appends( buf, _( "member" ) );
 			vips_buf_appends( buf, " " );
