@@ -795,7 +795,7 @@ icontainer_class_init( iContainerClass *class )
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET( iContainerClass, child_remove ),
 		NULL, NULL,
-		g_cclosure_marshal_VOID__POINTER,
+		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE, 1,
 		TYPE_ICONTAINER );
 
@@ -804,7 +804,7 @@ icontainer_class_init( iContainerClass *class )
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET( iContainerClass, current ),
 		NULL, NULL,
-		g_cclosure_marshal_VOID__POINTER,
+		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE, 1,
 		TYPE_ICONTAINER );
 
@@ -813,7 +813,7 @@ icontainer_class_init( iContainerClass *class )
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET( iContainerClass, child_detach ),
 		NULL, NULL,
-		g_cclosure_marshal_VOID__POINTER,
+		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE, 1,
 		TYPE_ICONTAINER );
 
