@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -527,7 +527,8 @@ idialog_build( GtkWidget *widget )
 	else {
 		/* If there's just 1 OK, that gets Esc too.
 		 */
-		if( g_slist_length( idlg->ok_but_l ) == 1 )
+		if( idlg->ok_but_l &&
+			g_slist_length( idlg->ok_but_l ) == 1 )
 			gtk_widget_add_accelerator( 
 				GTK_WIDGET( idlg->ok_but_l->data ), "clicked", 
 				iwnd->accel_group, GDK_Escape, 0, 0 );
@@ -550,13 +551,6 @@ idialog_build( GtkWidget *widget )
 		idlg->destroy_sid = g_signal_connect( idlg->iobject, "destroy", 
 			G_CALLBACK( idialog_iobject_destroy ), idlg );
 
-	/* Set transient hint ... this may not have been set by our iwindow
-	 * superclass if the lock-in-front pref is off.
-	 */
-        if( iwnd->parent_window ) 
-		gtk_window_set_transient_for( GTK_WINDOW( iwnd ),
-			GTK_WINDOW( iwnd->parent_window ) );
-
         gtk_widget_show( idlg->work );
 }
 
