@@ -16,9 +16,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -125,6 +125,18 @@ iwindow_number( void )
 	return( g_slist_length( iwindow_all ) );
 }
 
+/* Pick an iwindow at random. Used if we need a window for a dialog, and we're
+ * not sure which to pick. During shutdown we can have no windows. 
+ */
+iWindow *
+iwindow_pick_one( void )
+{
+	if( !iwindow_all )
+		return( NULL ); 
+
+	return( IWINDOW( iwindow_all->data ) );
+}
+
 /* Over all windows.
  */
 void *
@@ -423,6 +435,13 @@ iwindow_susp_return( void *sys, iWindowResult result )
         im_free( susp );
 }
 
+void
+iwindow_susp_trigger( iWindowSusp *susp )
+{
+	susp->fn( susp->iwnd, susp->client, susp->nfn, susp->sys );
+	im_free( susp );
+}
+
 /* Compose two iWindowFns ... if this one succeeded, trigger the next in turn.
  * Otherwise bail out.
  */
@@ -431,10 +450,8 @@ iwindow_susp_comp( void *sys, iWindowResult result )
 {
 	iWindowSusp *susp = IWINDOW_SUSP( sys );
 
-	if( result == IWINDOW_YES ) {
-		susp->fn( susp->iwnd, susp->client, susp->nfn, susp->sys );
-		im_free( susp );
-	}
+	if( result == IWINDOW_YES ) 
+		iwindow_susp_trigger( susp ); 
 	else 
 		iwindow_susp_return( sys, result );
 }
@@ -531,9 +548,9 @@ iwindow_finalize( GObject *gobject )
 	G_OBJECT_CLASS( parent_class )->finalize( gobject );
 
 	/* Last window and we've got through startup? Quit the application.
-	 * Test for 1, since main() makes an invisible iwindow as the root.
 	 */
-	if( iwindow_number() == 1 && !main_starting )
+	if( iwindow_number() == 0 && 
+		!main_starting )
 		main_quit_test();
 }
 
@@ -549,6 +566,8 @@ iwindow_destroy( GtkObject *gobject )
 	/* My instance destroy stuff.
 	 */
 	FREESID( iwnd->parent_unmap_sid, iwnd->parent_window );
+	UNREF( iwnd->action_group ); 
+	UNREF( iwnd->ui_manager ); 
 
 	/* Now we've destroyed, we must stop popdown from being called, since 
 	 * the view will have junked a lot of stuff.
@@ -746,7 +765,9 @@ iwindow_real_build( GtkWidget *widget )
 	/* Link to parent.
 	 */
         if( iwnd->parent_window ) {
-		if( IWINDOW_GET_CLASS( iwnd )->transient )
+		if( IWINDOW_GET_CLASS( iwnd )->transient &&
+			iwnd->parent_window &&
+			iwnd != iwnd->parent_window )
 			gtk_window_set_transient_for( GTK_WINDOW( iwnd ),
 				GTK_WINDOW( iwnd->parent_window ) );
 
@@ -1020,7 +1041,8 @@ iwindow_get_root_noparent( GtkWidget *widget )
 	/* If this is a transient, get the window we popped up from.
 	 */
 	if( IS_IWINDOW( toplevel ) && IWINDOW( toplevel )->parent ) 
-		return( iwindow_get_root( IWINDOW( toplevel )->parent ) );
+		return( iwindow_get_root_noparent( 
+			IWINDOW( toplevel )->parent ) );
 	else
 		return( toplevel );
 }
