@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -40,16 +40,13 @@ typedef struct _Matrixview {
 
 	GtkWidget *box;			/* Top level hbox we lay out in */
 
-	/* If we're displaying a matrix. We use the liststore if we can't
-	 * builf gtksheet on this gtk.
+	/* If we're displaying a matrix with a gtktreeview. 
 	 */
 	GtkListStore *store;
 	GtkWidget *sheet;
 	GtkWidget *swin;
-	char *cell_text;		/* Last text set ... for edit detect */
-	int cell_row, cell_col;		/* Position of text */
 
-	/* Displaying a table of widgets.
+	/* Displaying a table of widgets: sliders or toggles. 
 	 */
 	GtkWidget *table;		/* Matrix table */
 	GSList *items; 			/* Widgets for elems */
