@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -143,8 +143,8 @@ paintboxview_scale_change_cb( Tslider *tslider, Paintboxview *pbv )
 }
 
 static void
-paintboxview_double_cb( GtkWidget *wid, 
-	Paintboxview *pbv, guint state )
+paintboxview_double_cb( GtkWidget *wid, GdkEvent *event, 
+	Paintboxview *pbv )
 {
 	imageinfo_colour_edit( wid, IMAGEDISPLAY( pbv->ink )->conv->ii );
 }
@@ -355,6 +355,7 @@ paintboxview_init( Paintboxview *pbv )
 		GTK_WIDGET( pbv->nib ), FALSE, TRUE, 0 );
         gtk_signal_connect( GTK_OBJECT( pbv->nib ), "changed", 
 		GTK_SIGNAL_FUNC( paintboxview_scale_change_cb ), pbv );
+	tslider_set_ignore_scroll( pbv->nib, FALSE );
 
 	pbv->ink = (GtkWidget *) colourdisplay_new( NULL );
         doubleclick_add( GTK_WIDGET( pbv->ink ), FALSE,
