@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -38,7 +38,6 @@
  */
 enum {
 	NAME_COLUMN,			/* Kit or tool name */
-	NAME_I18N_COLUMN,		/* Localised tool name */
 	TOOL_POINTER_COLUMN,		/* Pointer to tool */
 	KIT_POINTER_COLUMN,		/* Pointer to kit (if no tool) */
 	N_COLUMNS
@@ -114,10 +113,10 @@ program_refresh_trim( Program *program, GtkTreePath *path )
 
 static void
 program_refresh_update( Program *program, GtkTreePath *path,
-	const char *name, const char *name_i18n, Tool *tool, Toolkit *kit )
+	const char *name, Tool *tool, Toolkit *kit )
 {
 	GtkTreeIter iter;
-	
+
 	/* Update, or append if there's nothing to update.
 	 */
 	if( gtk_tree_model_get_iter( GTK_TREE_MODEL( program->store ), 
@@ -125,21 +124,18 @@ program_refresh_update( Program *program, GtkTreePath *path,
 		/* Node exists.
  		 */
 		char *store_name;
-		char *store_name_i18n;
 		Tool *store_tool;
 		Toolkit *store_kit;
 
 		gtk_tree_model_get( GTK_TREE_MODEL( program->store ), &iter,
 			NAME_COLUMN, &store_name,
-			NAME_I18N_COLUMN, &store_name_i18n,
 			TOOL_POINTER_COLUMN, &store_tool,
 			KIT_POINTER_COLUMN, &store_kit,
 			-1 );
 
 		if( tool != store_tool ||
 			kit != store_kit ||
-			my_strcmp( name, store_name ) != 0 ||
-			my_strcmp( name_i18n, store_name_i18n ) != 0 ) {
+			my_strcmp( name, store_name ) != 0 ) {
 #ifdef DEBUG_TREE
 			printf( "program_refresh_update: updating \"%s\"\n",
 				name );
@@ -147,14 +143,12 @@ program_refresh_update( Program *program, GtkTreePath *path,
 			gtk_tree_store_set( program->store, 
 				&iter,
 				NAME_COLUMN, name,
-				NAME_I18N_COLUMN, name_i18n,
 				TOOL_POINTER_COLUMN, tool,
 				KIT_POINTER_COLUMN, kit,
 				-1 );
 		}
 
 		g_free( store_name );
-		g_free( store_name_i18n );
 
 		/* Make sure tool nodes have no children ... this can happen 
 		 * after some drags.
@@ -197,7 +191,6 @@ program_refresh_update( Program *program, GtkTreePath *path,
 		gtk_tree_store_append( program->store, &iter, piter );
 		gtk_tree_store_set( program->store, &iter,
 			NAME_COLUMN, name,
-			NAME_I18N_COLUMN, name_i18n,
 			TOOL_POINTER_COLUMN, tool,
 			KIT_POINTER_COLUMN, kit,
 			-1 );
@@ -209,12 +202,10 @@ program_refresh_tool( Tool *tool, Program *program, GtkTreePath *path )
 {
 	if( tool->toolitem )
 		program_refresh_update( program, path,
-			IOBJECT( tool )->name, tool->toolitem->name,
-			tool, tool->kit );
+			IOBJECT( tool )->name, tool, tool->kit );
 	else
 		program_refresh_update( program, path,
-			IOBJECT( tool )->name, NULL,
-			tool, tool->kit );
+			IOBJECT( tool )->name, tool, tool->kit );
 
 	gtk_tree_path_next( path );
 
@@ -225,7 +216,7 @@ static void *
 program_refresh_kit( Toolkit *kit, Program *program, GtkTreePath *path )
 {
 	program_refresh_update( program, path,
-		IOBJECT( kit )->name, NULL, NULL, kit );
+		IOBJECT( kit )->name, NULL, kit );
 
 	gtk_tree_path_down( path );
 	toolkit_map( kit, 
@@ -317,13 +308,17 @@ program_row_lookup( Program *program, Model *model, GtkTreeIter *return_iter )
 }
 
 static gboolean
-program_refresh_timeout( Program *program )
+program_refresh_timeout( gpointer user_data )
 {
-	GtkTreePath *path;
-	GtkTreeIter iter;
+	Program *program = PROGRAM( user_data ); 
+	iWindow *iwnd = IWINDOW( program );
+	Model *model = program_get_selected( program );
 	GtkTreeSelection *select = 
 		gtk_tree_view_get_selection( GTK_TREE_VIEW( program->tree ) );
-	Model *model = program_get_selected( program );
+
+	GtkTreePath *path;
+	GtkTreeIter iter;
+        GtkAction *action;
 
 	program->refresh_timeout = 0;
 
@@ -390,6 +385,11 @@ program_refresh_timeout( Program *program )
 	g_signal_handler_unblock( G_OBJECT( select ), 
 		program->select_changed_sid );
 
+	action = gtk_action_group_get_action( iwnd->action_group, 
+		"DefBrowser" );
+	gtk_toggle_action_set_active( GTK_TOGGLE_ACTION( action ),
+		program->rpane->open );
+
 	return( FALSE );
 }
 
@@ -400,9 +400,9 @@ program_refresh( Program *program )
 {
 	IM_FREEF( g_source_remove, program->refresh_timeout );
 	
-	/* 1ms to make sure we run after idle (is this right?)
+	/* 10ms to make sure we run after idle (is this right?)
 	 */
-	program->refresh_timeout = g_timeout_add( 1, 
+	program->refresh_timeout = g_timeout_add( 10, 
 		(GSourceFunc) program_refresh_timeout, program );
 }
 
@@ -619,7 +619,7 @@ program_edit_dia( Program *program, Tool *tool )
 {
 	GtkWidget *ss = stringset_new();
 
-	g_assert( tool->type == TOOL_DIA );
+	g_assert( tool && tool->type == TOOL_DIA );
 
 	stringset_child_new( STRINGSET( ss ), 
 		_( "Name" ), IOBJECT( tool )->name, _( "Menu item text" ) );
@@ -703,7 +703,7 @@ program_remove_object_cb( GtkWidget *menu, Program *program )
 	Model *model = program_get_selected( program );
 
 	if( model )
-		model_check_destroy( GTK_WIDGET( program ), model );
+		model_check_destroy( GTK_WIDGET( program ), model, NULL );
 }
 
 static void
@@ -773,6 +773,8 @@ program_init( Program *program )
 	program->tree = NULL;
 	program->store = NULL;
 	program->pane_position = PROGRAM_PANE_POSITION;
+	program->rpane_open = FALSE;
+	program->rpane_position = 500;
 	program->refresh_timeout = 0;
 
 	program->kitgroup_changed_sid = 0;
@@ -832,15 +834,94 @@ program_kit_destroy( Toolkit *kit, Program *program )
 	program_refresh( program );
 }
 
+/* Is a character one of those allowed in nip2 identifers?
+ */
+static gboolean
+is_ident( int ch )
+{
+	if( isalnum( ch ) ||
+		ch == '_' ||
+		ch == '\'' )
+		return( TRUE );
+
+	return( FALSE );
+}
+
+static void 
+program_text_cursor_position( GtkTextBuffer *buffer, GParamSpec *pspec, 
+	Program *program )
+{
+	gboolean editable = !program->kit || !program->kit->pseudo;
+
+	if( program->rpane_open && 
+		editable ) {
+		/* Fetch characters left of the cursor while we have stuff
+		 * that could be an identifier.
+		 */
+		GtkTextIter start;
+		GtkTextIter cursor;
+		GtkTextIter end;
+		char *line;
+		char *p, *q, *r;
+
+		/* Get iters for start / cursor / end of line.
+		 */
+		gtk_text_buffer_get_iter_at_mark( buffer,
+			&cursor, gtk_text_buffer_get_insert( buffer ) );
+		gtk_text_buffer_get_iter_at_line_index( buffer,
+			&start, gtk_text_iter_get_line( &cursor ), 0 ); 
+		gtk_text_buffer_get_iter_at_line_index( buffer,
+			&end, gtk_text_iter_get_line( &cursor ), 0 ); 
+		gtk_text_iter_forward_to_line_end( &end );
+
+		line = gtk_text_buffer_get_text( buffer, &start, &end, FALSE );
+		p = line + gtk_text_iter_get_line_index( &cursor );
+
+		/* Search back from the cursor for the first non-identifier
+		 * char.
+		 */
+		for( q = p - 1; q >= line && is_ident( *q ); q-- )
+			;
+		q += 1;
+		for( r = p; r < line + strlen( line ) && is_ident( *r ); r++ )
+			;
+		*r= '\0';
+
+		if( strlen( q ) > 1 )
+			defbrowser_set_filter( program->defbrowser, q );
+
+		g_free( line );
+	}
+}
+
+static void
+program_text_changed( GtkTextBuffer *buffer, Program *program )
+{
+	if( !program->dirty ) {
+		program->dirty = TRUE;
+		program_refresh( program );
+	}
+}
+
 static void
 program_set_text( Program *program, const char *text, gboolean editable )
 {
+	GtkTextView *text_view = GTK_TEXT_VIEW( program->text );
+	GtkTextBuffer *text_buffer = gtk_text_view_get_buffer( text_view );
 	guint text_hash = g_str_hash( text );
 
 	if( text_hash != program->text_hash ) {
-		text_view_set_text( GTK_TEXT_VIEW( program->text ), 
-			text, editable );
+		/* Stop ::changed from firing, we don't want it to update the
+		 * def browser filter.
+		 */
+		g_signal_handlers_block_by_func( text_buffer,
+			G_CALLBACK( program_text_cursor_position ), program );
+
+		text_view_set_text( text_view, text, editable );
 		program->text_hash = text_hash;
+
+		g_signal_handlers_unblock_by_func( text_buffer,
+			G_CALLBACK( program_text_cursor_position ), program );
 	}
 
 	program->dirty = FALSE;
@@ -1019,7 +1100,8 @@ program_parse( Program *program )
 	}
 
 	program->dirty = FALSE;
-	filemodel_set_modified( FILEMODEL( program->kit ), TRUE );
+	if( program->kit )
+		filemodel_set_modified( FILEMODEL( program->kit ), TRUE );
 
 	/* Reselect last_sym, the last thing the parser saw. 
 	 */
@@ -1036,7 +1118,8 @@ program_tool_new_action_cb( GtkAction *action, Program *program )
 {
 	/* Existing text changed? Parse it.
 	 */
-	if( program->dirty && !program_parse( program ) ) {
+	if( program->dirty && 
+		!program_parse( program ) ) {
 		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_ERROR );
 		return;
 	}
@@ -1192,13 +1275,6 @@ program_program_new_action_cb( GtkAction *action, Program *program )
 	gtk_widget_show( GTK_WIDGET( program2 ) ); 
 }
 
-static void
-program_workspace_new_action_cb( GtkAction *action, Program *program )
-{
-	workspacegroup_workspace_new( main_workspacegroup, 
-		GTK_WIDGET( program ) );
-}
-
 static void *
 program_load_file_fn( Filesel *filesel, 
 	const char *filename, Program *program, void *b )
@@ -1374,7 +1450,7 @@ program_remove_tool_action_cb( GtkAction *action, Program *program )
 	Model *model = program_get_selected( program );
 
 	if( model && IS_TOOL( model ) )
-		model_check_destroy( GTK_WIDGET( program ), model );
+		model_check_destroy( GTK_WIDGET( program ), model, NULL );
 	else {
 		error_top( _( "No tool selected" ) );
 		iwindow_alert( GTK_WIDGET( program ), GTK_MESSAGE_INFO );
@@ -1387,7 +1463,8 @@ program_remove_toolkit_action_cb( GtkAction *action, Program *program )
 	if( !program_check_kit( program ) )
 		return;
 
-	model_check_destroy( GTK_WIDGET( program ), MODEL( program->kit ) );
+	model_check_destroy( GTK_WIDGET( program ), 
+		MODEL( program->kit ), NULL );
 }
 
 static void
@@ -1602,17 +1679,22 @@ program_errorreport_action_cb( GtkAction *action, Program *program )
 static void
 program_tool_help_action_cb( GtkAction *action, Program *program )
 {
-	char txt[512];
-	VipsBuf buf = VIPS_BUF_STATIC( txt );
-
 	if( program->tool && program->tool->type == TOOL_SYM && 
 		program->kit && program->kit->pseudo ) {
 		switch( program->tool->sym->type ) {
 		case SYM_EXTERNAL:
+			/* With vips7 we displayed the man page. When we go
+			 * properly vips8, display the API docs.
+			 *
+	char txt[512];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
+
 			vips_buf_appendf( &buf, "file://"
 				VIPS_DOCPATH "/man/%s.3.html", 
 				IOBJECT( program->tool->sym )->name );
 			box_url( GTK_WIDGET( program ), vips_buf_all( &buf ) );
+			 *
+			 */
 			break;
 
 		case SYM_BUILTIN:
@@ -1631,6 +1713,17 @@ program_tool_help_action_cb( GtkAction *action, Program *program )
 	}
 }
 
+/* Expose/hide the definition browser.
+ */
+static void
+program_defbrowser_action_cb( GtkToggleAction *action, Program *program )
+{
+	if( gtk_toggle_action_get_active( action ) )
+		pane_animate_open( program->rpane );
+	else
+		pane_animate_closed( program->rpane );
+}
+
 /* Our actions.
  */
 static GtkActionEntry program_actions[] = {
@@ -1665,11 +1758,6 @@ static GtkActionEntry program_actions[] = {
 		N_( "Make a new program window" ), 
 		G_CALLBACK( program_program_new_action_cb ) },
 
-	{ "NewWorkspace", 
-		GTK_STOCK_NEW, N_( "New _Workspace" ), NULL, 
-		N_( "Make a new workspace" ), 
-		G_CALLBACK( program_workspace_new_action_cb ) },
-
 	{ "Open", 
 		GTK_STOCK_OPEN, N_( "_Open Toolkit" ), NULL,
 		N_( "_Open toolkit" ), 
@@ -1771,6 +1859,13 @@ static GtkActionEntry program_actions[] = {
 		G_CALLBACK( program_tool_help_action_cb ) }
 };
 
+static GtkToggleActionEntry program_toggle_actions[] = {
+	{ "DefBrowser",
+		NULL, N_( "Definition _Browser" ), NULL,
+		N_( "Show definition browser" ),
+		G_CALLBACK( program_defbrowser_action_cb ), FALSE }
+};
+
 static const char *program_menubar_ui_description =
 "<ui>"
 "  <menubar name='ProgramMenubar'>"
@@ -1781,7 +1876,6 @@ static const char *program_menubar_ui_description =
 "        <menuitem action='NewSeparator'/>"
 "        <menuitem action='NewColumnItem'/>"
 "        <menuitem action='NewProgram'/>"
-"        <menuitem action='NewWorkspace'/>"
 "      </menu>"
 "      <menuitem action='Open'/>"
 "      <separator/>"
@@ -1812,6 +1906,9 @@ static const char *program_menubar_ui_description =
 "      <separator/>"
 "      <menuitem action='Info'/>"
 "    </menu>"
+"    <menu action='ViewMenu'>"
+"      <menuitem action='DefBrowser'/>"
+"    </menu>"
 "    <menu action='DebugMenu'>"
 "      <menuitem action='Trace'/>"
 "      <menuitem action='Errors'/>"
@@ -1826,6 +1923,23 @@ static const char *program_menubar_ui_description =
 "  </menubar>"
 "</ui>";
 
+static void
+program_lpane_changed_cb( Pane *pane, Program *program )
+{
+}
+
+static void
+program_rpane_changed_cb( Pane *pane, Program *program )
+{
+	if( program->rpane_open != pane->open ||
+		program->rpane_position != pane->user_position ) {
+		program->rpane_open = pane->open;
+		program->rpane_position = pane->user_position;
+
+		program_refresh( program );
+	}
+}
+
 gboolean
 program_select( Program *program, Model *model )
 {
@@ -1844,15 +1958,6 @@ program_select( Program *program, Model *model )
 	return( TRUE );
 }
 
-static void
-program_text_changed( GtkTextBuffer *buffer, Program *program )
-{
-	if( !program->dirty ) {
-		program->dirty = TRUE;
-		program_refresh( program );
-	}
-}
-
 /* Select a row from an iter.
  */
 static void
@@ -2107,7 +2212,7 @@ program_text_new( void )
 	GtkWidget *text;
 
 	text = gtk_text_view_new();
-	font_desc = pango_font_description_from_string( "Mono" );
+	font_desc = pango_font_description_from_string( "Monospace" );
 	gtk_widget_modify_font( text, font_desc );
 	pango_font_description_free( font_desc );
 	tabs = program_tabs_new();
@@ -2130,12 +2235,17 @@ program_build( Program *program, GtkWidget *vbox )
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select;
 	GtkWidget *swin;
+	Panechild *panechild;
+	GtkWidget *ebox;
 
         /* Make main menu bar
          */
 	gtk_action_group_add_actions( iwnd->action_group, 
 		program_actions, G_N_ELEMENTS( program_actions ), 
 		GTK_WINDOW( program ) );
+	gtk_action_group_add_toggle_actions( iwnd->action_group, 
+		program_toggle_actions, G_N_ELEMENTS( program_toggle_actions ), 
+		GTK_WINDOW( program ) );
 
 	error = NULL;
 	if( !gtk_ui_manager_add_ui_from_string( iwnd->ui_manager,
@@ -2165,21 +2275,30 @@ program_build( Program *program, GtkWidget *vbox )
 			GTK_WIDGET( IWINDOW( program )->infobar ), 
 			FALSE, FALSE, 0 );
 
-	program->pane = gtk_hpaned_new();
-	gtk_paned_set_position( GTK_PANED( program->pane ), 
+	program->rpane = pane_new( PANE_HIDE_RIGHT );
+	g_signal_connect( program->rpane, "changed",
+		G_CALLBACK( program_rpane_changed_cb ), program );
+	gtk_box_pack_start( GTK_BOX( vbox ), 
+		GTK_WIDGET( program->rpane ), TRUE, TRUE, 0 );
+	gtk_widget_show( GTK_WIDGET( program->rpane ) );
+
+	program->lpane = pane_new( PANE_HIDE_LEFT );
+	g_signal_connect( program->lpane, "changed",
+		G_CALLBACK( program_lpane_changed_cb ), program );
+	gtk_paned_set_position( GTK_PANED( program->lpane ), 
 		program->pane_position );
-	gtk_box_pack_start( GTK_BOX( vbox ), program->pane, TRUE, TRUE, 0 );
-	gtk_widget_show( program->pane );
+	gtk_paned_pack1( GTK_PANED( program->rpane ), 
+		GTK_WIDGET( program->lpane ), TRUE, FALSE );
+	gtk_widget_show( GTK_WIDGET( program->lpane ) );
 
 	swin = gtk_scrolled_window_new( NULL, NULL );
 	gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW( swin ),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-	gtk_paned_pack1( GTK_PANED( program->pane ), swin, FALSE, FALSE );
+	gtk_paned_pack1( GTK_PANED( program->lpane ), swin, FALSE, FALSE );
 	gtk_widget_show( swin );
 
 	program->store = gtk_tree_store_new( N_COLUMNS, 
 		G_TYPE_STRING, 
-		G_TYPE_STRING,
 		G_TYPE_POINTER,
 		G_TYPE_POINTER );
 	program->row_inserted_sid = g_signal_connect( 
@@ -2197,15 +2316,12 @@ program_build( Program *program, GtkWidget *vbox )
 		renderer, "text", NAME_COLUMN, NULL );
 	gtk_tree_view_append_column( GTK_TREE_VIEW( program->tree ), column );
 
-	renderer = gtk_cell_renderer_text_new();
-	column = gtk_tree_view_column_new_with_attributes( _( "Name" ),
-		renderer, "text", NAME_I18N_COLUMN, NULL );
-	gtk_tree_view_append_column( GTK_TREE_VIEW( program->tree ), column );
-
 	g_signal_connect( G_OBJECT( program->tree ), "row_collapsed",
 		G_CALLBACK( program_row_collapsed_cb ), program );
 
 	gtk_container_add( GTK_CONTAINER( swin ), program->tree );
+	gtk_tree_view_set_headers_visible( GTK_TREE_VIEW( program->tree ), 
+		FALSE );
 	gtk_tree_view_set_enable_search( GTK_TREE_VIEW( program->tree ), TRUE );
 	gtk_tree_view_set_reorderable( GTK_TREE_VIEW( program->tree ), TRUE );
 	select = gtk_tree_view_get_selection( GTK_TREE_VIEW( program->tree ) );
@@ -2217,17 +2333,41 @@ program_build( Program *program, GtkWidget *vbox )
 		GTK_SIGNAL_FUNC( program_tree_event_cb ), program );
 	gtk_widget_show( program->tree );
 
+	/* Toolkit Browser pane.
+	 */
+	panechild = panechild_new( program->rpane, _( "Definition Browser" ) );
+
+	/* Have to put toolkitbrowser in an ebox so the search entry gets
+	 * clipped to the pane size.
+	 */
+	ebox = gtk_event_box_new();
+	gtk_container_add( GTK_CONTAINER( panechild ), GTK_WIDGET( ebox ) );
+	gtk_widget_show( ebox );
+
+	program->defbrowser = defbrowser_new();
+	vobject_link( VOBJECT( program->defbrowser ), 
+		IOBJECT( program->kitg ) );
+	defbrowser_set_program( program->defbrowser, program );
+	gtk_container_add( GTK_CONTAINER( ebox ), 
+		GTK_WIDGET( program->defbrowser ) );
+	gtk_widget_show( GTK_WIDGET( program->defbrowser ) );
+
 	swin = gtk_scrolled_window_new( NULL, NULL );
 	gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW( swin ),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-	gtk_paned_pack2( GTK_PANED( program->pane ), swin, TRUE, TRUE );
+	gtk_paned_pack2( GTK_PANED( program->lpane ), swin, TRUE, TRUE );
 	gtk_widget_show( swin );
 
 	program->text = program_text_new();
-        g_signal_connect( 
+	g_signal_connect(
+		gtk_text_view_get_buffer( GTK_TEXT_VIEW( program->text ) ),
+		"notify::cursor-position",
+                G_CALLBACK( program_text_cursor_position ), program );
+	g_signal_connect(
 		gtk_text_view_get_buffer( GTK_TEXT_VIEW( program->text ) ),
 		"changed",
                 G_CALLBACK( program_text_changed ), program );
+
 	gtk_container_add( GTK_CONTAINER( swin ), program->text );
 	gtk_widget_show( program->text );
 
@@ -2240,12 +2380,12 @@ program_popdown( iWindow *iwnd, void *client, iWindowNotifyFn nfn, void *sys )
 	Program *program = PROGRAM( iwnd );
 
 	prefs_set( "PROGRAM_PANE_POSITION", "%d", 
-		gtk_paned_get_position( GTK_PANED( program->pane ) ) );
+		gtk_paned_get_position( GTK_PANED( program->lpane ) ) );
 
-        if( program->dirty && !program_parse( program ) )
-                nfn( sys, IWINDOW_ERROR );
-        else
-                nfn( sys, IWINDOW_YES );
+	/* We can't parse in popdown, we may have lost too much of the rest of 
+	 * nip2 before here.
+	 */
+	nfn( sys, IWINDOW_YES );
 }
 
 static void
@@ -2268,6 +2408,9 @@ program_link( Program *program, Toolkitgroup *kitg )
 	program->kitgroup_destroy_sid = 
 		g_signal_connect( G_OBJECT( program->kitg ), "destroy",
 			G_CALLBACK( program_kitgroup_destroy ), program );
+
+	pane_set_state( program->rpane, 
+		program->rpane_open, program->rpane_position );
 }
 
 Program *
