@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -411,7 +411,7 @@ regionview_border_foreach( Regionview *regionview,
 /* Repaint ... as a rect_foreach function.
  */
 static void *
-regionview_queue_draw_area( Regionview *regionview, Rect *area )
+regionview_queue_draw_area( Regionview *regionview, Rect *area, void *dummy )
 {
 #ifdef DEBUG_PAINT
 	printf( "regionview_queue_draw_area: at %dx%d size %dx%d\n",
@@ -440,28 +440,28 @@ regionview_queue_draw( Regionview *regionview )
 	case REGIONVIEW_REGION:
 		conversion_im_to_disp_rect( conv, area, &dr );
 		(void) regionview_border_foreach( regionview, &dr, 
-			(regionview_rect_fn) regionview_queue_draw_area, NULL );
+			regionview_queue_draw_area, NULL );
 		break;
 
 	case REGIONVIEW_MARK:
 		conversion_im_to_disp( conv, area->left, area->top, &x, &y );
 		(void) regionview_crosshair_foreach( regionview, x, y, 
-			(regionview_rect_fn) regionview_queue_draw_area, NULL );
+			regionview_queue_draw_area, NULL );
 		break;
 
 	case REGIONVIEW_ARROW:
 		conversion_im_to_disp_rect( conv, area, &dr );
 		(void) regionview_crosshair_foreach( regionview, 
 			dr.left, dr.top,
-			(regionview_rect_fn) regionview_queue_draw_area, NULL );
+			regionview_queue_draw_area, NULL );
 		(void) regionview_crosshair_foreach( regionview, 
 			IM_RECT_RIGHT( &dr ), 
 			IM_RECT_BOTTOM( &dr ),
-			(regionview_rect_fn) regionview_queue_draw_area, NULL );
+			regionview_queue_draw_area, NULL );
 
 		im_rect_normalise( &dr );
 		im_rect_marginadjust( &dr, 2 );
-		regionview_queue_draw_area( regionview, &dr );
+		regionview_queue_draw_area( regionview, &dr, NULL );
 
 		break;
 
@@ -471,7 +471,7 @@ regionview_queue_draw( Regionview *regionview )
 		conversion_im_to_disp_rect( conv, area, &dr );
 		im_rect_normalise( &dr );
 		im_rect_marginadjust( &dr, 2 );
-		regionview_queue_draw_area( regionview, &dr );
+		regionview_queue_draw_area( regionview, &dr, NULL );
 		break;
 
 	case REGIONVIEW_BOX:
@@ -479,7 +479,7 @@ regionview_queue_draw( Regionview *regionview )
 		im_rect_normalise( &dr );
 		im_rect_marginadjust( &dr, -2 );
 		(void) regionview_border_foreach( regionview, &dr, 
-			(regionview_rect_fn) regionview_queue_draw_area, NULL );
+			regionview_queue_draw_area, NULL );
 		break;
 
 	default:
@@ -587,14 +587,13 @@ regionview_destroy( GtkObject *object )
 	Imagedisplay *id;
 
 #ifdef DEBUG_MAKE
-	printf( "regionview_destroy: %p\n", regionview );
+	printf( "regionview_destroy: %p\n", object );
 #endif /*DEBUG_MAKE*/
 
 	g_return_if_fail( object != NULL );
 	g_return_if_fail( IS_REGIONVIEW( object ) );
 
 	regionview = REGIONVIEW( object );
-	id = regionview->ip->id;
 
 	if( !regionview->first ) 
 		regionview_queue_draw( regionview ); 
@@ -602,11 +601,14 @@ regionview_destroy( GtkObject *object )
 
 	regionview_detach( regionview );
 
-	FREESID( regionview->expose_sid, id ); 
-	FREESID( regionview->destroy_sid, id ); 
-	FREESID( regionview->event_sid, id ); 
-	FREESID( regionview->changed_sid, id->conv ); 
-	FREESID( regionview->conv_destroy_sid, id->conv ); 
+	if( (id = regionview->ip->id) ) { 
+		FREESID( regionview->expose_sid, id ); 
+		FREESID( regionview->destroy_sid, id ); 
+		FREESID( regionview->event_sid, id ); 
+		FREESID( regionview->changed_sid, id->conv ); 
+		FREESID( regionview->conv_destroy_sid, id->conv ); 
+	}
+
 	FREESID( regionview->model_changed_sid, regionview->classmodel ); 
 	IM_FREEF( g_source_remove, regionview->dash_crawl );
 	IM_FREEF( iwindow_cursor_context_destroy, regionview->cntxt );
@@ -784,21 +786,6 @@ regionview_get_model( Regionview *regionview )
 	return( model_area );
 }
 
-/* Are we in a ws in 7.8 compatibility mode? If we are, we need to offset x/y 
- * by image xoffset/yoffset.
- */
-static gboolean
-regionview_get_compatibility( Regionview *regionview )
-{
-	Classmodel *classmodel = regionview->classmodel;
-
-	if( classmodel && HEAPMODEL( classmodel )->row &&
-		HEAPMODEL( classmodel )->row->ws )
-		return( HEAPMODEL( classmodel )->row->ws->compat_78 );
-
-	return( FALSE );
-}
-
 /* Update our_area from the model. Translate to our cods too: we always have
  * x/y in 0 to xsize/ysize.
  */
@@ -815,14 +802,6 @@ regionview_update_from_model( Regionview *regionview )
 
 	regionview->our_area = *model_area;
 
-	if( regionview_get_compatibility( regionview ) ) {
-		Conversion *conv = regionview->ip->id->conv;
-		IMAGE *im = imageinfo_get( FALSE, conv->ii );
-
-		regionview->our_area.left += im->Xoffset;
-		regionview->our_area.top += im->Yoffset;
-	}
-
 #ifdef DEBUG
 	printf( "regionview_update_from_model: set regionview to %dx%d size %dx%d\n",
 		regionview->our_area.left, regionview->our_area.top, 
@@ -836,7 +815,6 @@ static void
 regionview_model_update( Regionview *regionview )
 {
 	Classmodel *classmodel = regionview->classmodel;
-	Imagepresent *ip = regionview->ip;
 	Rect *model_area = regionview_get_model( regionview );
 
 #ifdef DEBUG
@@ -847,14 +825,6 @@ regionview_model_update( Regionview *regionview )
 
 	*model_area = regionview->our_area;
 
-	if( regionview_get_compatibility( regionview ) ) {
-		Conversion *conv = ip->id->conv;
-		IMAGE *im = imageinfo_get( FALSE, conv->ii );
-
-		model_area->left -= im->Xoffset;
-		model_area->top -= im->Yoffset;
-	}
-
 	if( classmodel ) {
 		classmodel_update( classmodel );
 
@@ -940,7 +910,7 @@ regionview_clone_cb( GtkWidget *menu, Regionview *regionview, Imagepresent *ip )
 
         workspace_deselect_all( ws );
         row_select( row );
-        if( !workspace_clone_selected( ws ) )
+        if( !workspace_selected_duplicate( ws ) )
 		iwindow_alert( GTK_WIDGET( regionview ), GTK_MESSAGE_ERROR );
         workspace_deselect_all( ws );
 
@@ -1201,7 +1171,8 @@ regionview_rect_touches_region( Regionview *regionview, Rect *expose )
 	case REGIONVIEW_VGUIDE:
 		conversion_im_to_disp_rect( conv, 
 			&regionview->area, &canvas_area );
-		im_rect_marginadjust( &canvas_area, 1 );
+		im_rect_marginadjust( &canvas_area, 5 );
+
 		if( regionview_rect_touching( regionview, 
 			&canvas_area, expose ) )
 			return( TRUE );
@@ -1359,15 +1330,9 @@ regionview_find_resize( Regionview *regionview, int x, int y )
 
 		break;
 
-	case REGIONVIEW_HGUIDE:
-		im_rect_marginadjust( &canvas_area, 1 );
-		if( im_rect_includespoint( &canvas_area, x, y ) )
-			return( REGIONVIEW_RESIZE_MOVE );
-
-		break;
-
 	case REGIONVIEW_VGUIDE:
-		im_rect_marginadjust( &canvas_area, 1 );
+	case REGIONVIEW_HGUIDE:
+		im_rect_marginadjust( &canvas_area, 5 );
 		if( im_rect_includespoint( &canvas_area, x, y ) )
 			return( REGIONVIEW_RESIZE_MOVE );
 
