@@ -16,9 +16,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -120,8 +120,8 @@ rhs_save( Model *model, xmlNode *xnode )
 	if( !(xthis = MODEL_CLASS( parent_class )->save( model, xnode )) )
 		return( NULL );
 
-	if( !set_prop( xthis, "vislevel", "%d", rhs->vislevel ) ||
-		!set_prop( xthis, "flags", "%d", rhs->flags ) )
+	if( !set_iprop( xthis, "vislevel", rhs->vislevel ) ||
+		!set_iprop( xthis, "flags", rhs->flags ) )
 		return( NULL );
 
 	return( xthis );
@@ -173,7 +173,9 @@ rhs_refresh_graphic( Rhs *rhs, PElement *root )
 
 	/* Only for non-parameter class objects.
 	 */
-	if( result && row->sym->type != SYM_PARAM ) {
+	if( result && 
+		row->sym &&
+		row->sym->type != SYM_PARAM ) {
 		for( i = 0; i < IM_NUMBER( rhs_graphic ); i++ ) {
 			const char *name = rhs_graphic[i].name;
 
@@ -224,7 +226,9 @@ rhs_new_heap( Heapmodel *heapmodel, PElement *root )
 	 */
 	if( !heap_is_class( root, &result ) ) 
 		return( rhs );
-	if( result && row->sym->type != SYM_PARAM ) {
+	if( result && 
+		row->sym &&
+		row->sym->type != SYM_PARAM ) {
 		if( !rhs->scol || !IS_SUBCOLUMN( rhs->scol ) ) 
 			subcolumn_new( rhs, NULL );
 	}
