@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -50,6 +50,7 @@ toolkitbrowser_destroy( GtkObject *object )
 {
 	Toolkitbrowser *toolkitbrowser = TOOLKITBROWSER( object );
 
+	UNREF( toolkitbrowser->filter );
 	UNREF( toolkitbrowser->store );
 
 	GTK_OBJECT_CLASS( parent_class )->destroy( object );
@@ -126,13 +127,26 @@ toolkitbrowser_refresh( vObject *vobject )
 #endif /*DEBUG*/
 
 	gtk_list_store_clear( toolkitbrowser->store );
-	toolkitgroup_map( toolkitbrowser->mainw->ws->kitg,
+	toolkitgroup_map( toolkitbrowser->kitg,
 		(toolkit_map_fn) toolkitbrowser_rebuild_item, 
 		toolkitbrowser, NULL );
 
 	VOBJECT_CLASS( parent_class )->refresh( vobject );
 }
 
+static void
+toolkitbrowser_link( vObject *vobject, iObject *iobject )
+{
+	Toolkitbrowser *toolkitbrowser = TOOLKITBROWSER( vobject );
+	Toolkitgroup *kitg = TOOLKITGROUP( iobject );
+
+	g_assert( !toolkitbrowser->kitg );
+
+	toolkitbrowser->kitg = kitg;
+
+	VOBJECT_CLASS( parent_class )->link( vobject, iobject );
+}
+
 static void
 toolkitbrowser_class_init( ToolkitbrowserClass *class )
 {
@@ -144,6 +158,7 @@ toolkitbrowser_class_init( ToolkitbrowserClass *class )
 	object_class->destroy = toolkitbrowser_destroy;
 
 	vobject_class->refresh = toolkitbrowser_refresh;
+	vobject_class->link = toolkitbrowser_link;
 }
 
 static void
@@ -202,10 +217,10 @@ toolkitbrowser_get_selected( Toolkitbrowser *toolkitbrowser )
 static gboolean
 toolkitbrowser_activate_selected( Toolkitbrowser *toolkitbrowser )
 {
-	Toolitem *toolitem = toolkitbrowser_get_selected( toolkitbrowser ); 
+	Toolitem *toolitem;
 
-        if( toolitem ) {
-		if( !workspace_add_action( toolkitbrowser->mainw->ws, 
+        if( (toolitem = toolkitbrowser_get_selected( toolkitbrowser )) ) {
+		if( !workspace_add_action( toolkitbrowser->ws, 
 			toolitem->name, toolitem->action, 
 			toolitem->action_sym->expr->compile->nparam ) )
 			return( FALSE );
@@ -323,18 +338,6 @@ toolkitbrowser_get_type( void )
 	return( type );
 }
 
-void
-toolkitbrowser_set_mainw( Toolkitbrowser *toolkitbrowser, Mainw *mainw )
-{
-	g_assert( !toolkitbrowser->mainw );
-
-#ifdef DEBUG
-	printf( "toolkitbrowser_set_mainw:\n" );
-#endif /*DEBUG*/
-
-	toolkitbrowser->mainw = mainw;
-}
-
 Toolkitbrowser *
 toolkitbrowser_new( void )
 {
@@ -353,3 +356,11 @@ toolkitbrowser_get_width( Toolkitbrowser *toolkitbrowser )
 	else
 		return( 200 );
 }
+
+void
+toolkitbrowser_set_workspace( Toolkitbrowser *toolkitbrowser, Workspace *ws )
+{
+	g_assert( !toolkitbrowser->ws );
+
+	toolkitbrowser->ws = ws;
+}
