@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -35,14 +35,28 @@
 
 static ViewClass *parent_class = NULL;
 
+static void *
+toolkitgroupview_dispose_sub( View *view, void *a, void *b )
+{
+	DESTROY_GTK( view );
+
+	return( NULL );
+}
+
 static void
-toolkitgroupview_finalize( GObject *gobject )
+toolkitgroupview_dispose( GObject *gobject )
 {
 #ifdef DEBUG
-	printf( "toolkitgroupview_finalize: %p\n", gobject );
+	printf( "toolkitgroupview_dispose: %p\n", gobject );
 #endif /*DEBUG*/
 
-	G_OBJECT_CLASS( parent_class )->finalize( gobject );
+	/* Toolkitviews are not child widgets of us, they are menu items pased
+	 * into the TK. Destroy them explicitly.
+	 */
+	view_map( VIEW( gobject ), 
+		toolkitgroupview_dispose_sub, NULL, NULL ); 
+
+	G_OBJECT_CLASS( parent_class )->dispose( gobject );
 }
 
 static void 
@@ -71,7 +85,7 @@ toolkitgroupview_class_init( ToolkitgroupviewClass *class )
 
 	parent_class = g_type_class_peek_parent( class );
 
-	gobject_class->finalize = toolkitgroupview_finalize;
+	gobject_class->dispose = toolkitgroupview_dispose;
 
 	/* Create signals.
 	 */
@@ -120,17 +134,6 @@ toolkitgroupview_new( void )
 void
 toolkitgroupview_set_mainw( Toolkitgroupview *kitgview, Mainw *mainw )
 {
-	GtkWidget *item;
-
 	kitgview->mainw = mainw;
-
-	/* Fetch the menu we add toolkit menus to.
-	 */
-        item = gtk_ui_manager_get_widget( IWINDOW( mainw )->ui_manager,
-		"/MainwMenubar/ToolkitsMenu/Stub" );
-        kitgview->menu = gtk_widget_get_parent( GTK_WIDGET( item ) );
-
-	/* Remove the stub item.
-	 */
-	gtk_widget_destroy( item );
+        kitgview->menu = mainw->toolkit_menu;
 }
