@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -47,7 +47,7 @@ typedef struct _Watchgroup {
 
 	/* Workspaces we work within. Assume we are destroyed before this.
 	 */
-	Workspacegroup *workspacegroup;
+	Workspaceroot *workspaceroot;
 
 	/* Name of workspace our watchers check for their syms.
 	 */
@@ -71,7 +71,7 @@ typedef struct _WatchgroupClass {
 } WatchgroupClass;
 
 GType watchgroup_get_type( void );
-Watchgroup *watchgroup_new( Workspacegroup *workspacegroup, const char *name );
+Watchgroup *watchgroup_new( Workspaceroot *workspaceroot, const char *name );
 void watchgroup_flush( Watchgroup *watchgroup );
 
 /* Abstract base class for something that watches a row.
@@ -377,11 +377,11 @@ const char *watch_string_get( Watchgroup *,
 #define WORKSPACE_LPANE_OPEN \
 	(watch_bool_get( main_watchgroup, "WORKSPACE_LPANE_OPEN", FALSE ))
 #define WORKSPACE_LPANE_POSITION \
-	(watch_int_get( main_watchgroup, "WORKSPACE_LPANE_POSITION", 400 ))
+	(watch_int_get( main_watchgroup, "WORKSPACE_LPANE_POSITION", 200 ))
 #define WORKSPACE_RPANE_OPEN \
 	(watch_bool_get( main_watchgroup, "WORKSPACE_RPANE_OPEN", FALSE ))
 #define WORKSPACE_RPANE_POSITION \
-	(watch_int_get( main_watchgroup, "WORKSPACE_RPANE_POSITION", 100 ))
+	(watch_int_get( main_watchgroup, "WORKSPACE_RPANE_POSITION", 400 ))
 
 /* Heap size. Big enough to always load prefs, small enough that it doesn't 
  * trash the computer.
